@@ -16,7 +16,7 @@ gtable_add_col_space <- function(x, width) {
   if (n == 0) return(x)
   
   stopifnot(length(width) == 1 || length(width) == n)
-  width <- rep(width, length = n)
+  width <- rep(width, length.out = n)
 
   for(i in rev(seq_len(n))) {
     x <- gtable_add_cols(x, width[i], pos = i)
@@ -34,7 +34,7 @@ gtable_add_row_space <- function(x, height) {
   if (n == 0) return(x)
   
   stopifnot(length(height) == 1 || length(height) == n)
-  height <- rep(height, length = n)
+  height <- rep(height, length.out = n)
   
   for(i in rev(seq_len(n))) {
     x <- gtable_add_rows(x, height[i], pos = i)
